@@ -6,6 +6,10 @@ from jenkins_job_manager.xml_change import (
     UPDATE,
     DELETE,
 )
+from jenkins_job_manager.raw_ext import (
+    RawXmlProject,
+    XmlJobGeneratorWithRaw,
+)
 
 import fnmatch
 import glob
@@ -20,11 +24,10 @@ import xml.etree.ElementTree
 from typing import Dict, Optional
 
 import jenkins
-import jenkins_jobs.modules.base
 import jinja2
 from jenkins_jobs.parser import YamlParser
 from jenkins_jobs.registry import ModuleRegistry
-from jenkins_jobs.xml_config import XmlJob, XmlJobGenerator, XmlViewGenerator
+from jenkins_jobs.xml_config import XmlJob, XmlViewGenerator
 
 logging.basicConfig(level=logging.INFO)
 log = logging.getLogger("jjm")
@@ -106,11 +109,15 @@ class JenkinsJobManager:
         jenkins = self.jenkins
         views = self.views
         log.info("Reading jenkins views state")
+
         for view_d in jenkins.get_views():
             log.debug("found view %r", view_d)
             name, url, _class = view_d["name"], view_d["url"], view_d.get("_class")
-            if name == "all" or _class == "hudson.model.AllView":
-                log.debug("ignoring all view: %r", view_d)
+            if not self._jobs_filter_func(name):
+                log.debug("Ignored by filter: %s", name)
+                continue
+            if name == "All" or name == "all" or _class == "hudson.model.AllView":
+                log.debug("ignoring AllView: %r", view_d)
                 continue
             view_config = jenkins.get_view_config(name)
             views[name].before_xml = view_config
@@ -198,39 +205,6 @@ class JenkinsJobManager:
     def generate_jjb_xml(self):
         """render jjb yaml to xml"""
 
-        class RawXmlProject(jenkins_jobs.modules.base.Base):
-            """add a job type for raw xml"""
-
-            def root_xml(self, data):
-                xml_parent = xml.etree.ElementTree.fromstring(data["raw"])
-                return xml_parent
-
-        class XmlJobGeneratorWithRaw(XmlJobGenerator):
-            """bypasses the module loader for the raw xml job type"""
-
-            def _annotate_with_plugins(self, xml_job: XmlJob):
-                """Many elements coming out of jjb are missing plugin version data."""
-                plugins: dict = self.registry.plugins_dict
-                doc: xml.etree.ElementTree.Element = xml_job.xml
-                for node in doc.iterfind(".//*[@plugin]"):
-                    plugin_name = node.attrib["plugin"]
-                    if "@" in plugin_name:
-                        continue
-                    version = plugins[plugin_name]["version"]
-                    log.debug("annotated %r with %s@%s", node, plugin_name, version)
-                    node.attrib["plugin"] = f"{plugin_name}@{version}"
-
-            def _getXMLForData(self, data):
-                kind = data.get(self.kind_attribute, self.kind_default)
-                if kind == "raw":
-                    mod = RawXmlProject(self.registry)
-                    _xml = mod.root_xml(data)
-                    obj = XmlJob(_xml, data["name"])
-                    return obj
-                xml_job = super(XmlJobGenerator, self)._getXMLForData(data)
-                # self._annotate_with_plugins(xml_job)
-                return xml_job
-
         jjb_config = self.get_jjb_config()
         options_names = []  # normally a list of jobs globs for targeting
         files_path = glob.glob("./**/", recursive=True)
@@ -257,7 +231,9 @@ class JenkinsJobManager:
             formatted_xml_str = self.xml_dump(xml_job.xml)
             jobs[xml_job.name].after_xml = formatted_xml_str
 
-        xml_views = xml_view_generator.generateXML(view_data_list)
+        xml_views = xml_job_generator.generateXML(
+            filter(job_data_filter_wrapper, view_data_list)
+        )
         views = self.views
         for xml_view in xml_views:
             views[xml_view.name].after_xml = self.xml_dump(xml_view.xml)
